@@ -4,7 +4,7 @@
  * GChemPaint library
  * application.cc 
  *
- * Copyright (C) 2004-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -26,11 +26,13 @@
 #include "application.h"
 #include "document.h"
 #include "electron.h"
+#include "fragment.h"
 #include "text.h"
 #include "plugin.h"
 #include "mesomer.h"
 #include "mesomery.h"
 #include "mesomery-arrow.h"
+#include "molecule.h"
 #include "newfiledlg.h"
 #include "reaction.h"
 #include "reactant.h"
@@ -45,18 +47,25 @@
 #include "window.h"
 #include "zoomdlg.h"
 #include <gcu/filechooser.h>
+#include <gcu/loader.h>
 #include <goffice/utils/go-file.h>
-#include <sys/stat.h>
-#include <gconf/gconf-client.h>
-#include <libgnomevfs/gnome-vfs-mime.h>
-#include <libgnomevfs/gnome-vfs-ops.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
-#include <libgnomevfs/gnome-vfs-mime-info.h>
+#include <goffice/goffice.h>
+#ifndef HAVE_GO_CONF_SYNC
+#	include <gconf/gconf-client.h>
+#endif
+#include <gio/gio.h>
 #include <glib/gi18n-lib.h>
 #include <openbabel/mol.h>
+#include <openbabel/reaction.h>
 #include <openbabel/obconversion.h>
 #include <clocale>
 #include <fstream>
+#include <cstring>
+#include <sys/stat.h>
+
+using namespace OpenBabel;
+using namespace std;
+using namespace gcu;
 
 // following code is needed to get file extensions, it as been essentially copied from gnome-vfs
 static map<string, list<string> > globs;
@@ -170,6 +179,16 @@ static void load_globs ()
 namespace gcp {
 
 // Objects creation static methods
+static Object* CreateAtom ()
+{
+	return new Atom ();
+}
+
+static Object* CreateBond ()
+{
+	return new Bond ();
+}
+
 static Object* CreateMolecule ()
 {
 	return new Molecule ();
@@ -229,17 +248,20 @@ bool	Application::m_bInit = false;
 bool	Application::m_Have_Ghemical = false;
 bool	Application::m_Have_InChI = false;
 
-// FIXME: Remove for stable versions
-#undef PACKAGE
-#define PACKAGE "gchemutils-unstable" 
-
+#ifdef HAVE_GO_CONF_SYNC
+static void on_config_changed (GOConfNode *node, gchar const *key, Application *app)
+{
+	app->OnConfigChanged (node, key);
+}
+#else
 static void on_config_changed (GConfClient *client, guint cnxn_id, GConfEntry *entry, Application *app)
 {
 	app->OnConfigChanged (client, cnxn_id, entry);
 }
+#endif
 
 Application::Application ():
-	gcu::Application ("GChemPaint", DATADIR, "gchempaint-unstable", "gchempaint")
+	gcu::Application ("GChemPaint", DATADIR, "gchempaint", "gchempaint")
 {
 	m_CurZ = 6;
 	m_pActiveDoc = NULL;
@@ -247,6 +269,8 @@ Application::Application ():
 	m_NumWindow = 1;
 
 	if (!m_bInit) {
+		/* Initialize plugins manager */
+		gcu::Loader::Init ();
 		// Check for programs
 		char *result = NULL, *errors = NULL;
 		// check for ghemical
@@ -272,6 +296,8 @@ Application::Application ():
 		}
 
 		// Initialize types
+		Object::AddType ("atom", CreateAtom, AtomType);
+		Object::AddType ("bond", CreateBond, gcu::BondType);
 		Object::AddType ("molecule", CreateMolecule, MoleculeType);
 		Object::AddType ("reaction", CreateReaction, ReactionType);
 		Object::SetCreationLabel (ReactionType, _("Create a new reaction"));
@@ -324,13 +350,23 @@ Application::Application ():
 	load_globs ();
 	m_SupportedMimeTypes.push_back ("application/x-gchempaint");
 	m_WriteableMimeTypes.push_back ("application/x-gchempaint");
+	// browse available loaders
+	map<string, LoaderStruct>::iterator it;
+	bool found = Loader::GetFirstLoader (it);
+	while (found) {
+		if ((*it).second.supports2D) {
+			if ((*it).second.read)
+				AddMimeType (m_SupportedMimeTypes, (*it).first);
+			if ((*it).second.write)
+				AddMimeType (m_WriteableMimeTypes, (*it).first);
+		}
+		found = Loader::GetNextLoader (it);
+	}
 	// test if OpenBabel supports some extra types
 	TestSupportedType ("chemical/x-cml");
 	TestSupportedType ("chemical/x-mdl-molfile");
 	TestSupportedType ("chemical/x-pdb");
 	TestSupportedType ("chemical/x-xyz");
-	TestSupportedType ("chemical/x-cdx");
-	TestSupportedType ("chemical/x-cdxml");
 	TestSupportedType ("chemical/x-ncbi-asn1");
 	TestSupportedType ("chemical/x-ncbi-asn1-binary");
 	TestSupportedType ("chemical/x-ncbi-asn1-xml");
@@ -348,22 +384,29 @@ Application::Application ():
 		}
 	}
 	
-	m_ConfClient = gconf_client_get_default ();
-	gconf_client_add_dir (m_ConfClient, "/apps/gchempaint/settings", GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
+#ifdef HAVE_GO_CONF_SYNC
+	m_ConfNode = go_conf_get_node (GetConfDir (), GCP_CONF_DIR_SETTINGS);
+#else
 	GError *error = NULL;
-	GCU_GCONF_GET (ROOTDIR"compression", int, CompressionLevel, 0)
-	GCU_GCONF_GET (ROOTDIR"tearable-mendeleiev", bool, TearableMendeleiev, false)
+	m_ConfClient = gconf_client_get_default ();
+#endif
+	GCU_GCONF_GET ("compression", int, CompressionLevel, 0)
+	GCU_GCONF_GET ("tearable-mendeleiev", bool, TearableMendeleiev, false)
 	bool CopyAsText;
-	GCU_GCONF_GET (ROOTDIR"copy-as-text", bool, CopyAsText, false)
+	GCU_GCONF_GET ("copy-as-text", bool, CopyAsText, false)
 	ClipboardFormats = CopyAsText? GCP_CLIPBOARD_ALL: GCP_CLIPBOARD_NO_TEXT;
-	m_NotificationId = gconf_client_notify_add (m_ConfClient, "/apps/gchempaint/settings", (GConfClientNotifyFunc) on_config_changed, this, NULL, NULL);
+#ifdef HAVE_GO_CONF_SYNC
+	m_NotificationId = go_conf_add_monitor (m_ConfNode, NULL, (GOConfMonitorFunc) on_config_changed, this);
+#else
+	m_NotificationId = gconf_client_notify_add (m_ConfClient, "/apps/gchemutils/paint/settings", (GConfClientNotifyFunc) on_config_changed, this, NULL, NULL);
+#endif
 	// make themes permanent with this as a dummy client
 	list <string> Names = TheThemeManager.GetThemesNames ();
 	list <string>::iterator j, jend = Names.end ();
 	Theme *pTheme;
 	m_Dummy = new Object (0);
 	for (j = Names.begin (); j != jend; j++) {
-		pTheme = TheThemeManager.GetTheme ("Default");
+		pTheme = TheThemeManager.GetTheme (*j);
 		pTheme->AddClient (m_Dummy);
 	}
 }
@@ -377,7 +420,25 @@ Application::~Application ()
 	if (XmlDoc)
 		xmlFreeDoc (XmlDoc);
 	m_SupportedMimeTypes.clear ();
+	// remove themes permanency with this as a dummy client
+	list <string> Names = TheThemeManager.GetThemesNames ();
+	list <string>::iterator j, jend = Names.end ();
+	Theme *pTheme;
+	for (j = Names.begin (); j != jend; j++) {
+		pTheme = TheThemeManager.GetTheme (*j);
+		pTheme->RemoveClient (m_Dummy);
+	}
 	delete m_Dummy;
+#ifdef HAVE_GO_CONF_SYNC
+	go_conf_remove_monitor (m_NotificationId);
+	go_conf_free_node (m_ConfNode);
+	m_ConfNode = NULL;
+#else
+	gconf_client_notify_remove (m_ConfClient, m_NotificationId);
+	g_object_unref (m_ConfClient);
+	m_ConfClient = NULL;
+#endif
+	TheThemeManager.Shutdown ();
 }
 
 void Application::ActivateTool (const string& toolname, bool activate)
@@ -428,6 +489,8 @@ enum {
 	CHEMISTRY,
 	SVG,
 	EPS,
+	PDF,
+	PS,
 	PIXBUF
 };
 
@@ -451,6 +514,8 @@ bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bo
 	while ((i > 0) && (filename[i] != '.') && (filename[i] != '/')) i--;
 	if (filename[i] == '/') i = 0;
 	ext = (i > 0)? filename + i + 1: NULL;
+	if (!mime_type) // to be really sure we don't crash
+		mime_type = "application/x-gchempaint";
 	list<string>::iterator it, itend = m_SupportedMimeTypes.end ();
 	for (it =  m_SupportedMimeTypes.begin (); it != itend; it++)
 		if (*it == mime_type) {
@@ -462,6 +527,10 @@ bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bo
 			file_type = SVG;
 		else if (!strcmp (mime_type, "image/x-eps"))
 			file_type = EPS;
+		else if (!strcmp (mime_type, "application/pdf"))
+			file_type = PDF;
+		else if (!strcmp (mime_type, "application/ps"))
+			file_type = PS;
 		else if ((pixbuf_type = GetPixbufTypeName (filename2, mime_type))) {
 			file_type = PIXBUF;
 			if (!ext) {
@@ -474,15 +543,17 @@ bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bo
 		}
 	}
 	if (file_type < 0 || (!bSave && (file_type > CHEMISTRY))) {
+		char *mess = g_strdup_printf (_("Sorry, format %s not supported!\nFailed to load %s."), mime_type, filename);
 		GtkWidget* message = gtk_message_dialog_new (window, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
-													_("Sorry, format not supported!"));
+													mess);
 		gtk_dialog_run (GTK_DIALOG (message));
+		g_free (mess);
 		gtk_widget_destroy (message);
 		return true;
 	}
 	list<string> &exts = globs[mime_type];
 	bool err;
-	GnomeVFSURI *uri;
+	GFile *file;
 	if (bSave) {
 		char const *default_ext = (exts.size ())? exts.front ().c_str (): NULL;
 		if (ext) {
@@ -497,9 +568,8 @@ bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bo
 		}
 		if (default_ext && !ext)
 				filename2 += string(".") + default_ext;
-		uri = gnome_vfs_uri_new (filename2.c_str ());
-		err = gnome_vfs_uri_exists (uri);
-		gnome_vfs_uri_unref (uri);
+		file = g_file_new_for_uri (filename2.c_str ());
+		err = g_file_query_exists (file, NULL);
 		gint result = GTK_RESPONSE_YES;
 		if (err) {
 			gchar * message = g_strdup_printf (_("File %s\nexists, overwrite?"), filename2.c_str ());
@@ -510,8 +580,22 @@ bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bo
 			g_free (message);
 		}
 		if (result == GTK_RESPONSE_YES) {
-			// destroy the old file
-			gnome_vfs_unlink (filename2.c_str ());
+			// destroy the old file if needed
+			if (err) {
+				GError *error = NULL;
+				g_file_delete (file, NULL, &error);
+				if (error) {
+					gchar * message = g_strdup_printf (_("Error while processing %s:\n%s"), filename2.c_str (), error->message);
+					g_error_free (error);
+					GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message));
+					gtk_window_set_icon_name (GTK_WINDOW (Box), "gchempaint");
+					result = gtk_dialog_run (Box);
+					gtk_widget_destroy (GTK_WIDGET (Box));
+					g_free (message);
+					g_object_unref (file);
+					return false;
+				}
+			}
 			switch (file_type) {
 			case SVG:
 				m_pActiveDoc->ExportImage (filename2, "svg");
@@ -519,28 +603,36 @@ bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bo
 			case EPS:
 				m_pActiveDoc->ExportImage (filename2, "eps");
 				break;
+			case PDF:
+				m_pActiveDoc->ExportImage (filename2, "pdf");
+				break;
+			case PS:
+				m_pActiveDoc->ExportImage (filename2, "ps");
+				break;
 			case PIXBUF:
 				m_pActiveDoc->ExportImage (filename2, pixbuf_type, GetImageResolution ());
 				break;
 			default:
-				if (!strcmp (mime_type, "application/x-gchempaint"))
+				if (Save (filename2, mime_type, pDoc));
+				else if (!strcmp (mime_type, "application/x-gchempaint"))
 					SaveGcp (filename2, pDoc);
 				else
 					SaveWithBabel (filename2, mime_type, pDoc);
 			}
 		}
+		g_object_unref (file);
 	} else  { //loading
-		uri = gnome_vfs_uri_new (filename);
-		err = !gnome_vfs_uri_exists (uri);
-		gnome_vfs_uri_unref (uri);
+		file = g_file_new_for_uri (filename);
+		err = g_file_query_exists (file, NULL);
+		g_object_unref (file);
 		if (err) {
 			if (!ext) {
 				list<string>::iterator cur, end = exts.end ();
 				for (cur = exts.begin (); cur != end; cur++) {
 					filename2 = string (filename) + "." + *cur;
-					uri = gnome_vfs_uri_new (filename2.c_str ());
-					err = !gnome_vfs_uri_exists (uri);
-					gnome_vfs_uri_unref (uri);
+					file = g_file_new_for_uri (filename2.c_str ());
+					err = !g_file_query_exists (file, NULL);
+					g_object_unref (file);
 					if (!err)
 						break;
 				}
@@ -549,10 +641,31 @@ bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bo
 				filename2 = filename;
 			}
 		}
-		if (!strcmp (mime_type, "application/x-gchempaint"))
-			OpenGcp (filename2, pDoc);
-		else
-			OpenWithBabel (filename2, mime_type, pDoc);
+		bool create = false;
+		if (!pDoc || !pDoc->GetEmpty () || pDoc->GetDirty ()) {
+			create = true;
+			OnFileNew ();
+			pDoc = m_pActiveDoc;
+		}
+		pDoc->SetFileName(filename2, mime_type);
+		if (Load (filename2, mime_type, pDoc)) {
+			pDoc->GetView ()->AddObject (pDoc);
+			pDoc->GetView ()->Update (pDoc);
+			pDoc->GetView ()->EnsureSize ();
+			if (pDoc->GetWindow ())
+				pDoc->GetWindow ()->ActivateActionWidget ("/MainMenu/FileMenu/SaveAsImage", pDoc->HasChildren ());
+		} else {
+			if (create) {
+				pDoc->GetWindow ()->Destroy ();;
+				pDoc = NULL;
+				while (gdk_events_pending ())
+					gtk_main_iteration ();
+			}
+			if (!strcmp (mime_type, "application/x-gchempaint"))
+				OpenGcp (filename2, pDoc);
+			else
+				OpenWithBabel (filename2, mime_type, pDoc);
+		}
 	}
 	return false;
 }
@@ -575,68 +688,70 @@ void Application::SaveWithBabel (string const &filename, const gchar *mime_type,
 void Application::OpenWithBabel (string const &filename, const gchar *mime_type, Document* pDoc)
 {
 	string old_num_locale;
-	bool bNew = (pDoc == NULL || (!pDoc->GetEmpty () && ! pDoc->GetDirty ())), local;
-	GnomeVFSFileInfo *info = NULL;
-	bool result = false, read_only = false;
+	bool bNew = (pDoc == NULL || !pDoc->GetEmpty () || pDoc->GetDirty ());
+	GFile *file;
+	GFileInfo *info = NULL;
+	GError *error = NULL;
+	bool result = true, read_only = false;
+	gsize size = 0;
 	try {
 		if (!filename.length ())
 			throw (int) 0;
-		info = gnome_vfs_file_info_new ();
-		gnome_vfs_get_file_info (filename.c_str (), info, GNOME_VFS_FILE_INFO_DEFAULT);
-		local = GNOME_VFS_FILE_INFO_LOCAL (info);
-		if (!(info->permissions & (GNOME_VFS_PERM_USER_WRITE | GNOME_VFS_PERM_GROUP_WRITE)))
-			read_only = true;
-		gnome_vfs_file_info_unref (info);
+		file = g_file_new_for_uri (filename.c_str ());
+		info = g_file_query_info (file,
+								  G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE","G_FILE_ATTRIBUTE_STANDARD_SIZE,
+								  G_FILE_QUERY_INFO_NONE, NULL, &error);
+		if (error) {
+			g_warning ("GIO error: %s", error->message);
+			g_error_free (error);
+			if (info)
+				g_object_unref (info);
+			g_object_unref (file);
+			return;
+		}
+		size = g_file_info_get_size (info);
+		read_only = !g_file_info_get_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE);
+		g_object_unref (info);
 		if (bNew) {
 			OnFileNew ();
 			pDoc = m_pActiveDoc;
 		}
-		if (local) {
-			ifstream ifs;
-			GnomeVFSURI *uri = gnome_vfs_uri_new (filename.c_str ());
-			ifs.open (gnome_vfs_uri_get_path (uri));
-			gnome_vfs_uri_unref (uri);
-			if (ifs.fail ())
-				throw (int) 1;
-			old_num_locale = setlocale (LC_NUMERIC, NULL);
-			setlocale(LC_NUMERIC, "C");
-			OBMol Mol;
-			OBConversion Conv;
-			OBFormat* pInFormat = Conv.FormatFromMIME (mime_type);
-			if (pInFormat == NULL)
-				throw 1;
-			Conv.SetInFormat (pInFormat);
-			while (!ifs.eof () && Conv.Read (&Mol, &ifs)) {
-				result = pDoc->ImportOB(Mol);
-				Mol.Clear ();
-				if (!result)
-					break;
+		char *buf = new char[size + 1];
+		GInputStream *input = G_INPUT_STREAM (g_file_read (file, NULL, &error));
+		gsize n = 0;
+		while (n < size) {
+			n += g_input_stream_read (input, buf, size, NULL, &error);
+			if (error) {
+				g_message ("GIO could not read the file: %s", error->message);
+				g_error_free (error);
+				delete [] buf;
+				g_object_unref (input);
+				g_object_unref (file);
+				return;
 			}
-			setlocale (LC_NUMERIC, old_num_locale.c_str ());
-			ifs.close ();
-		} else {
-			char *buf;
-			int size;
-			if (gnome_vfs_read_entire_file (filename.c_str (), &size, &buf) != GNOME_VFS_OK)
-				throw 1;
-			istringstream iss (buf);
-			old_num_locale = setlocale (LC_NUMERIC, NULL);
-			setlocale(LC_NUMERIC, "C");
-			OBMol Mol;
-			OBConversion Conv;
-			OBFormat* pInFormat = Conv.FormatFromExt (filename.c_str ());
-			if (pInFormat == NULL)
-				throw 1;
-			Conv.SetInFormat (pInFormat);
-			while (!iss.eof () && Conv.Read (&Mol, &iss)) {
-				result = pDoc->ImportOB(Mol);
-				Mol.Clear ();
-				if (!result)
-					break;
-			}
-			setlocale (LC_NUMERIC, old_num_locale.c_str ());
-			g_free (buf);
 		}
+		g_object_unref (input);
+		g_object_unref (file);
+		buf[size] = 0;
+		istringstream iss (buf);
+		old_num_locale = setlocale (LC_NUMERIC, NULL);
+		setlocale(LC_NUMERIC, "C");
+		OBMol Mol;
+		OBConversion Conv;
+		OBFormat* pInFormat = Conv.FormatFromExt (filename.c_str ());
+		if (pInFormat == NULL) {
+			delete [] buf;
+			throw 1;
+		}
+		Conv.SetInFormat (pInFormat);
+		while (!iss.eof () && Conv.Read (&Mol, &iss)) {
+			result = pDoc->ImportOB(Mol);
+			Mol.Clear ();
+			if (!result)
+				break;
+		}
+		setlocale (LC_NUMERIC, old_num_locale.c_str ());
+		delete [] buf;
 		if (!result)
 		{
 			if (bNew)
@@ -678,22 +793,21 @@ void Application::OpenWithBabel (string const &filename, const gchar *mime_type,
 		switch (num)
 		{
 		case 0:
-			mess = g_strdup_printf(_("No filename"));
+			mess = _("No filename");
 			break;
 		case 1:
-			mess = g_strdup_printf(_("Could not open file\n%s"), filename.c_str ());
+			mess = _("Could not open file\n%s");
 			break;
 		case 2:
-			mess = g_strdup_printf(_("%s: parse error."), filename.c_str ());
+			mess = _("%s: parse error.");
 			break;
 		default:
 			throw (num); //this should not occur
 		}
-		message = gtk_message_dialog_new(NULL, (GtkDialogFlags) 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, mess);
+		message = gtk_message_dialog_new (NULL, (GtkDialogFlags) 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, mess, g_uri_unescape_string (filename.c_str (), NULL));
 		gtk_window_set_icon_name (GTK_WINDOW (message), "gchempaint");
 		g_signal_connect_swapped (G_OBJECT (message), "response", G_CALLBACK (gtk_widget_destroy), G_OBJECT (message));
 		gtk_widget_show(message);
-		g_free(mess);
 	}
 }
 
@@ -712,17 +826,23 @@ void Application::SaveGcp (string const &filename, Document* pDoc)
 	gtk_recent_manager_add_full (GetRecentManager (), filename.c_str (), &data);
 }
 
-static int	cb_vfs_to_xml (GnomeVFSHandle *handle, char* buf, int nb)
+static int	cb_vfs_to_xml (GInputStream *input, char* buf, int nb)
 {
-	GnomeVFSFileSize ndone;
-	return  (gnome_vfs_read (handle, buf, nb, &ndone) == GNOME_VFS_OK)? (int) ndone: -1;
+	GError *error = NULL;
+	int n = g_input_stream_read (input, buf, nb, NULL, &error);
+	if (error) {
+		g_message ("GIO error: %s", error->message);
+		g_error_free (error);
+	}
+	return n;
 }
 
 void Application::OpenGcp (string const &filename, Document* pDoc)
 {
 	xmlDocPtr xml = NULL;
 	char *old_num_locale, *old_time_locale;
-	GnomeVFSFileInfo *info = NULL;
+	GError *error = NULL;
+	GFileInfo *info = NULL;
 	bool create = false;
 	try
 	{
@@ -731,23 +851,33 @@ void Application::OpenGcp (string const &filename, Document* pDoc)
 
 		// try opening with write access to see if it is readonly
 		// use xmlReadIO for non local files.
-		info = gnome_vfs_file_info_new ();
-		gnome_vfs_get_file_info (filename.c_str (), info, GNOME_VFS_FILE_INFO_DEFAULT);
-
-		if (GNOME_VFS_FILE_INFO_LOCAL (info)) {
-			if (!(xml = xmlParseFile(filename.c_str ())))
-				throw (int) 1;
-		} else {
-			GnomeVFSHandle *handle;
-			GnomeVFSResult result = gnome_vfs_open (&handle, filename.c_str (), GNOME_VFS_OPEN_READ);
-			if (result != GNOME_VFS_OK)
-				throw 1;
-			if (!(xml = xmlReadIO ((xmlInputReadCallback) cb_vfs_to_xml, 
-					 (xmlInputCloseCallback) gnome_vfs_close, handle, filename.c_str (), NULL, 0)))
-				throw 1;
+		GFile *file = g_file_new_for_uri (filename.c_str ());
+		info = g_file_query_info (file,
+								  G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE,
+								  G_FILE_QUERY_INFO_NONE, NULL, &error);
+		if (error) {
+			g_object_unref (file);
+			g_message ("GIO error: %s\n", error->message);
+			g_error_free (error);
+			throw 1;
 		}
-		if (xml->children == NULL) throw (int) 2;
-		if (strcmp((char*)xml->children->name, "chemistry")) throw (int) 3;	//FIXME: that could change when a dtd is available
+		GInputStream *input = G_INPUT_STREAM (g_file_read (file, NULL, &error));
+		if (error) {
+			g_object_unref (file);
+			g_message ("GIO error: %s\n", error->message);
+			g_error_free (error);
+			throw 1;
+		}
+		if (!(xml = xmlReadIO ((xmlInputReadCallback) cb_vfs_to_xml, 
+				 (xmlInputCloseCallback) g_input_stream_close, input, filename.c_str (), NULL, 0))) {
+			g_object_unref (file);
+			throw 1;
+		}
+		g_object_unref (file);
+		if (xml->children == NULL)
+			throw (int) 2;
+		if (strcmp((char*)xml->children->name, "chemistry"))
+			throw (int) 3;	//FIXME: that could change when a dtd is available
 		old_num_locale = g_strdup(setlocale(LC_NUMERIC, NULL));
 		setlocale(LC_NUMERIC, "C");
 		old_time_locale = g_strdup(setlocale(LC_TIME, NULL));
@@ -768,9 +898,8 @@ void Application::OpenGcp (string const &filename, Document* pDoc)
 				pDoc->GetWindow ()->Destroy ();
 			throw (int) 4;
 		}
-		if (!(info->permissions & (GNOME_VFS_PERM_USER_WRITE | GNOME_VFS_PERM_GROUP_WRITE)))
-			pDoc->SetReadOnly (true);
-		gnome_vfs_file_info_unref (info);
+		pDoc->SetReadOnly (!g_file_info_get_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE));
+		g_object_unref (info);
 		xmlFreeDoc(xml);
 		GtkRecentData data;
 		data.display_name = (char*) pDoc->GetTitle ();
@@ -783,36 +912,36 @@ void Application::OpenGcp (string const &filename, Document* pDoc)
 	}
 	catch (int num)
 	{
+		if (num > 1)
+			xmlFreeDoc(xml);
 		if (info)
-			gnome_vfs_file_info_unref (info);
-		if (num > 1) xmlFreeDoc(xml);
+			g_object_unref (info);
 		gchar *mess = NULL;
 		GtkWidget* message;
 		switch (num)
 		{
 		case 0:
-			mess = g_strdup_printf(_("No filename"));
+			mess = _("No filename");
 			break;
 		case 1:
-			mess = g_strdup_printf(_("Could not load file\n%s"), filename.c_str ());
+			mess = _("Could not load file\n%s");
 			break;
 		case 2:
-			mess = g_strdup_printf(_("%s: invalid xml file.\nTree is empty?"), filename.c_str ());
+			mess = _("%s: invalid xml file.\nTree is empty?");
 			break;
 		case 3:
-			mess = g_strdup_printf(_("%s: invalid file format."), filename.c_str ());
+			mess = _("%s: invalid file format.");
 			break;
 		case 4:
-			mess = g_strdup_printf(_("%s: parse error."), filename.c_str ());
+			mess = _("%s: parse error.");
 			break;
 		default:
 			throw (num); //this should not occur
 		}
-		message = gtk_message_dialog_new(NULL, (GtkDialogFlags) 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, mess);
+		message = gtk_message_dialog_new(NULL, (GtkDialogFlags) 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, mess, g_uri_unescape_string (filename.c_str (), NULL));
 		gtk_window_set_icon_name (GTK_WINDOW (message), "gchempaint");
 		g_signal_connect_swapped (G_OBJECT (message), "response", G_CALLBACK (gtk_widget_destroy), G_OBJECT (message));
 		gtk_widget_show(message);
-		g_free(mess);
 	}
 }
 
@@ -832,6 +961,8 @@ void Application::OnSaveAsImage ()
 	map<string, GdkPixbufFormat*>::iterator i, end = m_SupportedPixbufFormats.end ();
 	for (i = m_SupportedPixbufFormats.begin (); i != end; i++)
 		l.push_front ((*i).first.c_str ());
+	l.push_front ("application/ps");
+	l.push_front ("application/pdf");
 	l.push_front ("image/x-eps");
 	l.push_front ("image/svg+xml");
 	FileChooser (this, true, l, m_pActiveDoc, _("Save as image"), GetImageResolutionWidget ());
@@ -1002,30 +1133,47 @@ void Application::ActivateWindowsActionWidget (const char *path, bool activate)
 	}
 }
 
+#ifdef HAVE_GO_CONF_SYNC
+void Application::OnConfigChanged (GOConfNode *node, gchar const *name)
+{
+#else
 void Application::OnConfigChanged (GConfClient *client, guint cnxn_id, GConfEntry *entry)
 {
 	if (client != m_ConfClient)
 		return;	// we might want an error message?
 	if (cnxn_id != m_NotificationId)
 		return;	// we might want an error message?
-	if (!strcmp (gconf_entry_get_key (entry),ROOTDIR"compression")) {
-		CompressionLevel = gconf_value_get_int (gconf_entry_get_value (entry));
-	} else 	if (!strcmp (gconf_entry_get_key (entry),ROOTDIR"tearable-mendeleiev")) {
-		TearableMendeleiev = gconf_value_get_bool (gconf_entry_get_value (entry));
-		Tools *ToolsBox = dynamic_cast<Tools*> (GetDialog ("tools"));
-		if (ToolsBox)
-			ToolsBox->Update ();
-	} else 	if (!strcmp (gconf_entry_get_key (entry),ROOTDIR"copy-as-text"))
-		ClipboardFormats = (gconf_value_get_bool (gconf_entry_get_value (entry)))? GCP_CLIPBOARD_ALL: GCP_CLIPBOARD_NO_TEXT;
+#endif
+	GCU_UPDATE_KEY ("compression", int, CompressionLevel, {})
+	GCU_UPDATE_KEY ("tearable-mendeleiev", bool, TearableMendeleiev,
+					{
+						Tools *ToolsBox = dynamic_cast<Tools*> (GetDialog ("tools"));
+						if (ToolsBox)
+							ToolsBox->Update ();
+					})
+	bool CopyAsText;
+	GCU_UPDATE_KEY ("copy-as-text", bool, CopyAsText, ClipboardFormats = CopyAsText?GCP_CLIPBOARD_ALL: GCP_CLIPBOARD_NO_TEXT;)
+}
+
+void Application::AddMimeType (list<string> &l, string const& mime_type)
+{
+	list<string>::iterator i, iend = l.end ();
+	for (i = l.begin (); i != iend; i++)
+		if (*i == mime_type)
+			break;
+	if (i == iend)
+		l.push_back (mime_type);
+	else
+		g_warning ("Duplicate mime type: %s", mime_type.c_str ());
 }
 
 void Application::TestSupportedType (char const *mime_type)
 {
 	OBFormat *f = OBConversion::FormatFromMIME (mime_type);
 	if (f != NULL) {
-		m_SupportedMimeTypes.push_back (mime_type);
+		AddMimeType (m_SupportedMimeTypes, mime_type);
 		if (!(f->Flags () & NOTWRITABLE))
-			m_WriteableMimeTypes.push_back (mime_type);
+			AddMimeType (m_WriteableMimeTypes, mime_type);
 	}
 }
 
@@ -1076,4 +1224,9 @@ void Application::AddOptions (GOptionContext *context)
 		g_option_context_add_main_entries (context, (*i).entries, (*i).translation_domain);
 }
 
+gcu::Document *Application::CreateNewDocument ()
+{
+	return new Document (this, true, NULL);
+}
+
 }	//	namespace gcp
