@@ -4,7 +4,7 @@
  * GChemPaint library
  * text.h 
  *
- * Copyright (C) 2002-2006 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -25,13 +25,19 @@
 #ifndef GCHEMPAINT_TEXT_H
 #define GCHEMPAINT_TEXT_H
 
+#include <gcu/macros.h>
 #include <gcu/object.h>
 #include <libxml/tree.h>
 #include <gtk/gtk.h>
 #include "text-object.h"
 
+/*!\file*/
 namespace gcp {
 
+/*!\class Text
+The text objects in GChemPaint, excluding atomic symbols. Using this class to
+represent chemical objects looses the chemical significance.
+*/
 class Text: public TextObject
 {
 public:
@@ -41,13 +47,13 @@ public:
 	
 	void GetCoords (double *x, double *y);
 	void SetCoords (double x, double y);
-	xmlNodePtr Save (xmlDocPtr xml);
-	xmlNodePtr SaveSelection (xmlDocPtr xml);
+	xmlNodePtr Save (xmlDocPtr xml) const;
+	xmlNodePtr SaveSelection (xmlDocPtr xml) const;
 	bool Load (xmlNodePtr);
 	bool LoadSelection (xmlNodePtr node, unsigned pos);
-	bool LoadNode (xmlNodePtr, unsigned &pos, int level = 0);
-	void Add (GtkWidget* w);
-	void Update (GtkWidget* w);
+	bool LoadNode (xmlNodePtr, unsigned &pos, int level = 0, int cur_size = 0);
+	void Add (GtkWidget* w) const;
+	void Update (GtkWidget* w) const;
 	void SetSelected (GtkWidget* w, int state);
 	bool OnChanged (bool save);
 	void Transform2D (gcu::Matrix2D& m, double x, double y);
@@ -55,6 +61,11 @@ public:
 	void GetSize (double& x, double& y) {x = m_length; y = m_height;}
 	double GetYAlign ();
 	void SetText (char const *text) {m_buf = text;}
+	bool SetProperty (unsigned property, char const *value);
+
+GCU_PROP (PangoAlignment, Align)
+GCU_PROP (bool, Justified)
+GCU_PROP (GtkAnchorType, Anchor)
 };
 
 }	//	namespace gcp
