@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * programs/3d/application.cc 
  *
- * Copyright (C) 2006 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2006-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -30,8 +30,6 @@
 #include <gcu/filechooser.h>
 #include <goffice/utils/go-image.h>
 #include <gsf/gsf-output-gio.h>
-#include <libgnomevfs/gnome-vfs-ops.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
 #include <cairo-pdf.h>
 #include <cairo-ps.h>
 #include <glib/gi18n.h>
@@ -40,7 +38,7 @@
 using namespace std;
 
 gc3dApplication::gc3dApplication (Display3DMode display3d, char const *bg):
-	Application (_("GChem3D Viewer"), DATADIR, "gchem3d-viewer-unstable"),
+	Application (_("GChem3D Viewer"), DATADIR, "gchem3d"),
 	m_Display3D (display3d)
 {
 	if (bg) {
@@ -159,9 +157,10 @@ bool gc3dApplication::FileProcess (const gchar* filename, const gchar* mime_type
 			gtk_widget_destroy (message);
 			return true;
 		}
-		GnomeVFSURI *uri = gnome_vfs_uri_new (filename2.c_str ());
-		bool err = gnome_vfs_uri_exists (uri);
-		gnome_vfs_uri_unref (uri);
+		GVfs *vfs = g_vfs_get_default ();
+		GFile *file = g_vfs_get_file_for_uri (vfs, filename2.c_str ());
+		GError *error = NULL;
+		bool err = g_file_query_exists (file, NULL);
 		gint result = GTK_RESPONSE_YES;
 		if (err) {
 			gchar * message = g_strdup_printf (_("File %s\nexists, overwrite?"), filename2.c_str ());
@@ -169,17 +168,19 @@ bool gc3dApplication::FileProcess (const gchar* filename, const gchar* mime_type
 			result = gtk_dialog_run (Box);
 			gtk_widget_destroy (GTK_WIDGET (Box));
 			g_free (message);
-			if (result == GTK_RESPONSE_YES)
-				gnome_vfs_unlink (filename2.c_str ());
-			else
+			if (result == GTK_RESPONSE_YES) {
+				g_file_delete (file, NULL, &error);
+				g_object_unref (file);
+			} else {
+				g_object_unref (file);
 				return true;
+			}
 		}
 		map <string, string> options; // not used at the moment
 		if (result == GTK_RESPONSE_YES) {
 			if (vrml)
 				pDoc->OnExportVRML (filename2);
 			else if (use_cairo) {
-				GError *error = NULL;
 				GsfOutput *output = gsf_output_gio_new_for_uri (filename, &error);
 				if (error) {
 					gchar * mess = g_strdup_printf (_("Could not create stream!\n%s"), error->message);
